==> moexalgo-2.0.0-py3-none-any.whl: moexalgo/__init__.py <==
from __future__ import annotations

from .currency import Currency
from .futures import Futures

try:
    from .__version__ import version as __version__
except ImportError:
    pass

import re
from typing import Union

from .market import Market
from .indices import Index
from .stocks import Stock
from .utils import CandlePeriod


def Ticker(secid: str, boardid: str = None) -> Union[Index, Stock]:
    """
    Получение объекта финансового инструмента по тикеру и типу рынка.

    Этот метод позволяет получить объект `Index` или `Stock`, содержащий информацию
    о финансовом инструменте, идентифицируемом по тикеру и, опционально, типу рынка.

    Parameters
    ----------
    secid : str
        Тикер финансового инструмента, например "GAZP" для акций Газпрома.
    boardid : str, optional
        Идентификатор рынка, на котором торгуется инструмент, 
        например "TQBR" для основного рынка акций на Московской бирже. 

    Notes
    -----
    По умолчанию значение `None` для `boardid` означает использование стандартного рынка.

    Returns
    -------
    return : Union[Index, Stock]
        Объект класса Index или Stock, содержащий информацию о запрашиваемом финансовом инструменте.

    Raises
    ------
    LookupError
        Исключение возникает, если тикер не найден на указанном рынке.

    Example
    -------
    .. code-block:: python
    
        # Получение информации об акции
        >>> try:
        >>>     instrument = Ticker("GAZP", "TQBR")
        >>>     print(instrument)
        >>> except LookupError:
        >>>     print("Тикер не найден.")
    """
    if boardid is None:
        secid, *args = re.split('\W', secid)
        if args:
            boardid = args[0]
    stocks = Market('stocks', boardid)
    if stocks._ticker_info(secid):
        return Stock(secid, stocks._boardid)

    currencies = Market('selt', boardid)
    if currencies._ticker_info(secid):
        return Currency(secid, currencies._boardid)

    indices = Market('index', boardid)
    if indices._ticker_info(secid):
        return Index(secid, indices._boardid)

    futures = Market('forts', boardid)
    if futures._ticker_info(secid):
        return Futures(secid, futures._boardid)

    raise LookupError(f"Cannot found ticker: `{secid}`")

==> moexalgo-2.3.2-py3-none-any.whl: moexalgo/__init__.py <==
from __future__ import annotations

import re
from typing import Union

from .tickers import _Ticker, _resolve_ticker

try:
    from .__version__ import version as __version__
except ImportError:
    pass

from .requests import get_secid_info_and_boards

from .market import Market
from .tickers import _Ticker
from .stocks import Stock
from .indices import Index
from .currency import Currency
from .futures import Futures
from .utils import CandlePeriod

AnyTickers = Union['Stock', 'Index', 'Currency', 'Futures']


def Ticker(secid: str, boardid: str = None) -> AnyTickers:
    """
    Получение объекта финансового инструмента по тикеру и типу рынка.

    Этот метод позволяет получить объект `Index` или `Stock`, содержащий информацию
    о финансовом инструменте, идентифицируемом по тикеру и, опционально, типу рынка.

    Parameters
    ----------
    secid : str
        Тикер финансового инструмента, например "GAZP" для акций Газпрома.
    boardid : str, optional
        Идентификатор рынка, на котором торгуется инструмент,
        например "TQBR" для основного рынка акций на Московской бирже.

    Notes
    -----
    По умолчанию значение `None` для `boardid` означает использование стандартного рынка.

    Returns
    -------
    return : Union[Index, Stock]
        Объект класса Index или Stock, содержащий информацию о запрашиваемом финансовом инструменте.

    Raises
    ------
    LookupError
        Исключение возникает, если тикер не найден на указанном рынке.

    Example
    -------
    .. code-block:: python

        # Получение информации об акции
        >>> try:
        >>>     instrument = Ticker("GAZP", "TQBR")
        >>>     print(instrument)
        >>> except LookupError:
        >>>     print("Тикер не найден.")
    """
    if info := _resolve_ticker(secid, boardid):
        secid, boardid, market, engine, *args = info
        allowed_tickers = dict((item._PATH, item) for item in [Currency, Futures, Index, Stock])
        if allowed_ticker := allowed_tickers.get(f'engines/{engine}/markets/{market}'):
            return allowed_ticker(*info)
    raise LookupError(f"Cannot found ticker: `{secid}`")
